@@ -44,12 +44,11 @@
 /* These items are set by Geany before plugin_init() is called. */
 GeanyPlugin		*geany_plugin;
 GeanyData			*geany_data;
-GeanyFunctions	*geany_functions;
 
 
 /* Check that the running Geany supports the plugin API version used below, and check
  * for binary compatibility. */
-PLUGIN_VERSION_CHECK(209)
+PLUGIN_VERSION_CHECK(224)
 PLUGIN_SET_TRANSLATABLE_INFO(
 	LOCALEDIR,
 	GETTEXT_PACKAGE,
@@ -89,7 +88,7 @@ static void on_paned_mode_changed(GtkToggleButton *button, gpointer user_data)
 void plugin_init(GeanyData *data)
 {
 	GtkWidget* vbox;
-	int i;
+	guint i;
 
 	plugin_module_make_resident(geany_plugin);
 
