@@ -29,7 +29,6 @@
 #include "geanydoc.h"
 
 extern GeanyData *geany_data;
-extern GeanyFunctions *geany_functions;
 
 const gchar defaults[] =
 	"[C]\n"
@@ -111,12 +110,12 @@ config_get_command(const gchar * lang, gint cmd_num, gboolean * intern)
 	gchar *key = g_strdup_printf("command%d", cmd_num);
 	ret = utils_get_setting_string(config, lang, key, "");
 	g_free(key);
-	if (!NZV(ret))
+	if (EMPTY(ret))
 		return ret;
 	key = g_strdup_printf("command%d", cmd_num + 1);
 	tmp = utils_get_setting_string(config, lang, key, "");
 	g_free(key);
-	if (NZV(tmp))
+	if (! EMPTY(tmp))
 		*intern = TRUE;
 	else
 		*intern = utils_get_setting_boolean(config, lang, "internal", FALSE);
