@@ -37,7 +37,6 @@
 /* These items are set by Geany before init() is called. */
 PluginFields *plugin_fields;
 GeanyData *geany_data;
-GeanyFunctions *geany_functions;
 
 static GtkWidget *keyb1;
 static GtkWidget *keyb2;
@@ -45,10 +44,11 @@ static GtkWidget *keyb2;
 
 /* Check that Geany supports plugin API version 128 or later, and check
  * for binary compatibility. */
-PLUGIN_VERSION_CHECK(128)
+PLUGIN_VERSION_CHECK(224)
 /* All plugins must set name, description, version and author. */
-	PLUGIN_SET_INFO(_("Doc"), _("Call documentation viewer on current symbol."), VERSION,
-		"Yura Siamshka <yurand2@gmail.com>")
+PLUGIN_SET_TRANSLATABLE_INFO(LOCALEDIR, GETTEXT_PACKAGE,
+	_("Doc"), _("Call documentation viewer on current symbol."), VERSION,
+	"Yura Siamshka <yurand2@gmail.com>")
 
 /* Keybinding(s) */
      enum
@@ -185,7 +185,7 @@ show_doc(const gchar * word, gint cmd_num)
 
 	ftype = doc->file_type->name;
 	command = config_get_command(ftype, cmd_num, &intern);
-	if (!NZV(command))
+	if (EMPTY(command))
 	{
 		g_free(command);
 		return;
@@ -201,7 +201,7 @@ show_doc(const gchar * word, gint cmd_num)
 	if (intern)
 	{
 		g_spawn_command_line_sync(command, &tmp, NULL, NULL, NULL);
-		if (NZV(tmp))
+		if (! EMPTY(tmp))
 		{
 			show_output(tmp, "*DOC*", NULL, doc->file_type->id);
 		}
@@ -271,11 +271,11 @@ on_comboboxType_changed(GtkComboBox * combobox, G_GNUC_UNUSED gpointer user_data
 
 	if (from != NULL)
 	{
-		if (NZV(cmd0_txt))
+		if (! EMPTY(cmd0_txt))
 			g_key_file_set_string(config, from, "command0", cmd0_txt);
 		else
 			g_key_file_remove_key(config, from, "command0", NULL);
-		if (NZV(cmd1_txt))
+		if (! EMPTY(cmd1_txt))
 			g_key_file_set_string(config, from, "command1", cmd1_txt);
 		else
 			g_key_file_remove_key(config, from, "command1", NULL);
@@ -436,7 +436,6 @@ plugin_init(G_GNUC_UNUSED GeanyData * data)
 	gchar *kb_label1;
 	gchar *kb_label2;
 
-	main_locale_init(LOCALEDIR, GETTEXT_PACKAGE);
 	kb_label1 = _("Document current word");
 	kb_label2 = _("Document interactive");
 
