@@ -37,11 +37,11 @@
 
 GeanyPlugin	*geany_plugin;
 GeanyData	*geany_data;
-GeanyFunctions	*geany_functions;
 
-PLUGIN_VERSION_CHECK(189)
+PLUGIN_VERSION_CHECK(224)
 
-PLUGIN_SET_INFO(_("Insert Numbers"), _("Insert/Fill columns with numbers."),
+PLUGIN_SET_TRANSLATABLE_INFO(LOCALEDIR, GETTEXT_PACKAGE,
+	_("Insert Numbers"), _("Insert/Fill columns with numbers."),
 	"0.2.2", "Dimitar Toshkov Zhekov <dimitar.zhekov@gmail.com>")
 
 /* Keybinding(s) */
@@ -468,7 +468,6 @@ void plugin_init(G_GNUC_UNUSED GeanyData *data)
 {
 	GeanyKeyGroup *plugin_key_group;
 
-	main_locale_init(LOCALEDIR, GETTEXT_PACKAGE);
 	plugin_key_group = plugin_set_key_group(geany_plugin, "insert_numbers", COUNT_KB, NULL);
 
 	start_value = 1;
