@@ -229,7 +229,7 @@ static gint glspi_batch(lua_State* L)
 /* Return the "word" at the given position */
 static gint glspi_word(lua_State* L)
 {
-	const gchar* word_chars = NULL;
+	const gchar* word_chars = GEANY_WORDCHARS;
 	gint pos,linenum, bol, bow, eow;
 	gchar *text=NULL;
 	DOC_REQUIRED
@@ -251,7 +251,6 @@ static gint glspi_word(lua_State* L)
 		if (lua_isstring(L, -1)) {
 			word_chars=lua_tostring(L, -1);
 		} else {
-			word_chars=GEANY_WORDCHARS;
 			lua_getglobal(L, LUA_MODULE_NAME);
 			lua_pushstring(L,tokenWordChars);
 			lua_pushstring(L,word_chars);
@@ -337,49 +336,49 @@ static gint glspi_lines(lua_State* L)
 
 static gint get_sci_nav_cmd(const gchar*str, gboolean fwd, gboolean sel, gboolean rect)
 {
-	if (strncasecmp(str, "char", 4) == 0) {
+	if (g_ascii_strncasecmp(str, "char", 4) == 0) {
 		if (fwd) {
 			return sel?(rect?SCI_CHARRIGHTRECTEXTEND:SCI_CHARRIGHTEXTEND):SCI_CHARRIGHT;
 		} else {
 			return sel?(rect?SCI_CHARLEFTRECTEXTEND:SCI_CHARLEFTEXTEND):SCI_CHARLEFT;
 		}
-	} else if (strncasecmp(str, "word", 4) == 0) {
+	} else if (g_ascii_strncasecmp(str, "word", 4) == 0) {
 		if (fwd) {
 			return sel?SCI_WORDRIGHTEXTEND:SCI_WORDRIGHT;
 		} else {
 			return sel?SCI_WORDLEFTEXTEND:SCI_WORDLEFT;
 		}
-	} else if (strncasecmp(str, "part", 4) == 0) {
+	} else if (g_ascii_strncasecmp(str, "part", 4) == 0) {
 		if (fwd) {
 			return sel?SCI_WORDPARTRIGHTEXTEND:SCI_WORDPARTRIGHT;
 		} else {
 			return sel?SCI_WORDPARTLEFTEXTEND:SCI_WORDPARTLEFT;
 		}
-	} else if (strncasecmp(str, "edge", 4) == 0) {
+	} else if (g_ascii_strncasecmp(str, "edge", 4) == 0) {
 		if (fwd) {
 			return sel?(rect?SCI_LINEENDRECTEXTEND:SCI_LINEENDEXTEND):SCI_LINEEND;
 		} else {
 			return sel?(rect?SCI_HOMERECTEXTEND:SCI_HOMEEXTEND):SCI_HOME;
 		}
-	} else if (strncasecmp(str, "line", 4) == 0) {
+	} else if (g_ascii_strncasecmp(str, "line", 4) == 0) {
 		if (fwd) {
 			return sel?(rect?SCI_LINEDOWNRECTEXTEND:SCI_LINEDOWNEXTEND):SCI_LINEDOWN;
 		} else {
 			return sel?(rect?SCI_LINEUPRECTEXTEND:SCI_LINEUPEXTEND):SCI_LINEUP;
 		}
-	} else if (strncasecmp(str, "para", 4) == 0) {
+	} else if (g_ascii_strncasecmp(str, "para", 4) == 0) {
 		if (fwd) {
 			return sel?SCI_PARADOWNEXTEND:SCI_PARADOWN;
 		} else {
 			return sel?SCI_PARAUPEXTEND:SCI_PARAUP;
 		}
-	} else if (strncasecmp(str, "page", 4) == 0) {
+	} else if (g_ascii_strncasecmp(str, "page", 4) == 0) {
 		if (fwd) {
 			return sel?(rect?SCI_PAGEDOWNRECTEXTEND:SCI_PAGEDOWNEXTEND):SCI_PAGEDOWN;
 		} else {
 			return sel?(rect?SCI_PAGEUPRECTEXTEND:SCI_PAGEUPEXTEND):SCI_PAGEUP;
 		}
-	} else if (strncasecmp(str, "body", 4) == 0) {
+	} else if (g_ascii_strncasecmp(str, "body", 4) == 0) {
 		if (fwd) {
 			return sel?SCI_DOCUMENTENDEXTEND:SCI_DOCUMENTEND;
 		} else {
@@ -758,6 +757,7 @@ static gint glspi_find(lua_State* L)
 
 	gint flags=0;
 	gint i,n;
+	gchar *text;
 	DOC_REQUIRED
 	switch (lua_gettop(L)) {
 		case 0:return FAIL_STRING_ARG(1);
@@ -771,7 +771,8 @@ static gint glspi_find(lua_State* L)
 	if (!lua_isnumber(L,3)) { return FAIL_NUMERIC_ARG(3); }
 	if (!lua_istable(L,4)) { return FAIL_TABLE_ARG(4); }
 
-	ttf.lpstrText=g_strdup(lua_tostring(L,1));
+	text=g_strdup(lua_tostring(L,1));
+	ttf.lpstrText=text;
 	ttf.chrg.cpMin=lua_tonumber(L,2);
 	ttf.chrg.cpMax=lua_tonumber(L,3);
 
@@ -780,15 +781,15 @@ static gint glspi_find(lua_State* L)
 		lua_rawgeti(L,4,i);
 		if (lua_isstring(L, -1)) {
 			const gchar*flagname=lua_tostring(L,-1);
-			if (strcasecmp(flagname, "matchcase")==0){
+			if (g_ascii_strcasecmp(flagname, "matchcase")==0){
 				flags += SCFIND_MATCHCASE;
-			} else if (strcasecmp(flagname, "wholeword")==0) {
+			} else if (g_ascii_strcasecmp(flagname, "wholeword")==0) {
 				flags += SCFIND_WHOLEWORD;
-			} else if (strcasecmp(flagname, "wordstart")==0) {
+			} else if (g_ascii_strcasecmp(flagname, "wordstart")==0) {
 				flags += SCFIND_WORDSTART;
-			} else if (strcasecmp(flagname, "regexp")==0) {
+			} else if (g_ascii_strcasecmp(flagname, "regexp")==0) {
 				flags += SCFIND_REGEXP;
-			} else if (strcasecmp(flagname, "posix")==0) {
+			} else if (g_ascii_strcasecmp(flagname, "posix")==0) {
 				flags += SCFIND_POSIX;
 			} else {
 				lua_pushfstring(L, _("Error in module \"%s\" at function %s():\n"
@@ -805,10 +806,10 @@ static gint glspi_find(lua_State* L)
 	if (scintilla_send_message(doc->editor->sci,SCI_FINDTEXT,flags,(sptr_t)&ttf)!=-1) {
 		push_number(L,ttf.chrgText.cpMin);
 		push_number(L,ttf.chrgText.cpMax);
-		g_free(ttf.lpstrText);
+		g_free(text);
 		return 2;
 	} else {
-		g_free(ttf.lpstrText);
+		g_free(text);
 		return 0;
 	}
 }
