@@ -29,8 +29,6 @@
 
 #include "geanyprj.h"
 
-extern GeanyData *geany_data;
-extern GeanyFunctions *geany_functions;
 
 static GtkWidget *file_view_vbox;
 static GtkWidget *file_view;
@@ -57,8 +55,7 @@ static struct
 
 
 /* Returns: the full filename in locale encoding. */
-static gchar *
-get_tree_path_filename(GtkTreePath * treepath)
+static gchar *get_tree_path_filename(GtkTreePath *treepath)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL(file_store);
 	GtkTreeIter iter;
@@ -71,9 +68,9 @@ get_tree_path_filename(GtkTreePath * treepath)
 	return name;
 }
 
+
 /* We use documents->open_files() as it's more efficient. */
-static void
-open_selected_files(GList * list)
+static void open_selected_files(GList *list)
 {
 	GSList *files = NULL;
 	GList *item;
@@ -85,12 +82,12 @@ open_selected_files(GList * list)
 		files = g_slist_append(files, fname);
 	}
 	document_open_files(files, FALSE, NULL, NULL);
-	g_slist_foreach(files, (GFunc) g_free, NULL);	// free filenames
+	g_slist_foreach(files, (GFunc)g_free, NULL);	/* free filenames */
 	g_slist_free(files);
 }
 
-static void
-on_open_clicked(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer user_data)
+
+static void on_open_clicked(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer user_data)
 {
 	GtkTreeSelection *treesel;
 	GtkTreeModel *model;
@@ -100,21 +97,21 @@ on_open_clicked(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer use
 
 	list = gtk_tree_selection_get_selected_rows(treesel, &model);
 	open_selected_files(list);
-	g_list_foreach(list, (GFunc) gtk_tree_path_free, NULL);
+	g_list_foreach(list, (GFunc)gtk_tree_path_free, NULL);
 	g_list_free(list);
 }
 
-static gboolean
-on_button_press(G_GNUC_UNUSED GtkWidget * widget, GdkEventButton * event,
-		G_GNUC_UNUSED gpointer user_data)
+
+static gboolean on_button_press(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event,
+								G_GNUC_UNUSED gpointer user_data)
 {
 	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS)
 		on_open_clicked(NULL, NULL);
 	return FALSE;
 }
 
-static GtkWidget *
-make_toolbar()
+
+static GtkWidget *make_toolbar(void)
 {
 	GtkWidget *toolbar;
 
@@ -125,8 +122,8 @@ make_toolbar()
 	return toolbar;
 }
 
-static void
-remove_selected_files(GList * list)
+
+static void remove_selected_files(GList *list)
 {
 	GList *item;
 	for (item = list; item != NULL; item = g_list_next(item))
@@ -138,8 +135,8 @@ remove_selected_files(GList * list)
 	}
 }
 
-static void
-on_remove_files(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer user_data)
+
+static void on_remove_files(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer user_data)
 {
 	GtkTreeSelection *treesel;
 	GtkTreeModel *model;
@@ -153,8 +150,8 @@ on_remove_files(G_GNUC_UNUSED GtkMenuItem * menuitem, G_GNUC_UNUSED gpointer use
 	g_list_free(list);
 }
 
-static gboolean
-on_key_press(G_GNUC_UNUSED GtkWidget * widget, GdkEventKey * event, G_GNUC_UNUSED gpointer data)
+
+static gboolean on_key_press(G_GNUC_UNUSED GtkWidget *widget, GdkEventKey *event, G_GNUC_UNUSED gpointer data)
 {
 	if (event->keyval == GDK_Return
 	    || event->keyval == GDK_ISO_Enter
@@ -163,8 +160,8 @@ on_key_press(G_GNUC_UNUSED GtkWidget * widget, GdkEventKey * event, G_GNUC_UNUSE
 	return FALSE;
 }
 
-static GtkWidget *
-create_popup_menu()
+
+static GtkWidget *create_popup_menu(void)
 {
 	GtkWidget *item, *menu, *image;
 
@@ -252,12 +249,14 @@ create_popup_menu()
 	return menu;
 }
 
-static void
-update_popup_menu(G_GNUC_UNUSED GtkWidget * popup_menu)
+
+static void update_popup_menu(G_GNUC_UNUSED GtkWidget *popup_menu)
 {
 	gboolean cur_file_exists;
 	gboolean badd_file;
 	GeanyDocument *doc;
+	GtkTreeSelection *treesel;
+	gboolean bremove_file;
 
 	doc = document_get_current();
 
@@ -267,8 +266,8 @@ update_popup_menu(G_GNUC_UNUSED GtkWidget * popup_menu)
 		!g_current_project->regenerate &&
 		cur_file_exists && !g_hash_table_lookup(g_current_project->tags, doc->file_name);
 
-	GtkTreeSelection *treesel = gtk_tree_view_get_selection(GTK_TREE_VIEW(file_view));
-	gboolean bremove_file = (g_current_project ? TRUE : FALSE) &&
+	treesel = gtk_tree_view_get_selection(GTK_TREE_VIEW(file_view));
+	bremove_file = (g_current_project ? TRUE : FALSE) &&
 		!g_current_project->regenerate &&
 		(gtk_tree_selection_count_selected_rows(treesel) > 0);
 
@@ -283,10 +282,10 @@ update_popup_menu(G_GNUC_UNUSED GtkWidget * popup_menu)
 	gtk_widget_set_sensitive(popup_items.find_in_files, g_current_project ? TRUE : FALSE);
 }
 
-// delay updating popup menu until the selection has been set
-static gboolean
-on_button_release(G_GNUC_UNUSED GtkWidget * widget, GdkEventButton * event,
-		  G_GNUC_UNUSED gpointer user_data)
+
+/* delay updating popup menu until the selection has been set */
+static gboolean on_button_release(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event,
+									G_GNUC_UNUSED gpointer user_data)
 {
 	if (event->button == 3)
 	{
@@ -303,12 +302,12 @@ on_button_release(G_GNUC_UNUSED GtkWidget * widget, GdkEventButton * event,
 	return FALSE;
 }
 
-static void
-prepare_file_view()
+
+static void prepare_file_view(void)
 {
 	GtkCellRenderer *text_renderer;
 	GtkTreeViewColumn *column;
-	GtkTreeSelection *select;
+	GtkTreeSelection *selection;
 	PangoFontDescription *pfd;
 
 	file_store = gtk_list_store_new(FILEVIEW_N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING);
@@ -330,9 +329,9 @@ prepare_file_view()
 	gtk_widget_modify_font(file_view, pfd);
 	pango_font_description_free(pfd);
 
-	// selection handling
-	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(file_view));
-	gtk_tree_selection_set_mode(select, GTK_SELECTION_SINGLE);
+	/* selection handling */
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(file_view));
+	gtk_tree_selection_set_mode(selection, GTK_SELECTION_SINGLE);
 
 	g_signal_connect(G_OBJECT(file_view), "button-release-event",
 			 G_CALLBACK(on_button_release), NULL);
@@ -342,14 +341,14 @@ prepare_file_view()
 	g_signal_connect(G_OBJECT(file_view), "key-press-event", G_CALLBACK(on_key_press), NULL);
 }
 
-void
-sidebar_clear()
+
+static void sidebar_clear(void)
 {
 	gtk_list_store_clear(file_store);
 }
 
-gint
-mycmp(const gchar * a, const gchar * b)
+#if 0
+static gint mycmp(const gchar *a, const gchar *b)
 {
 	const gchar *p1 = a;
 	const gchar *p2 = b;
@@ -396,9 +395,9 @@ mycmp(const gchar * a, const gchar * b)
 		return 1;
 	return -1;
 }
+#endif
 
-static void
-add_item(gpointer name, G_GNUC_UNUSED gpointer value, gpointer user_data)
+static void add_item(gpointer name, G_GNUC_UNUSED gpointer value, gpointer user_data)
 {
 	gchar *item;
 	GSList **lst = (GSList **) user_data;
@@ -407,14 +406,17 @@ add_item(gpointer name, G_GNUC_UNUSED gpointer value, gpointer user_data)
 	*lst = g_slist_prepend(*lst, item);
 }
 
-// recreate the tree model from current_dir.
-void
-sidebar_refresh()
+
+/* recreate the tree model from current_dir */
+void sidebar_refresh(void)
 {
 	GtkTreeIter iter;
 	GSList *lst = NULL;
 	GSList *tmp;
 
+	if (! file_view_vbox)
+		return;
+
 	sidebar_clear();
 
 	if (!g_current_project)
@@ -431,8 +433,8 @@ sidebar_refresh()
 	g_slist_free(lst);
 }
 
-void
-create_sidebar()
+
+void create_sidebar(void)
 {
 	GtkWidget *scrollwin, *toolbar;
 
@@ -454,8 +456,9 @@ create_sidebar()
 				 file_view_vbox, gtk_label_new(_("Project")));
 }
 
-void
-destroy_sidebar()
+
+void destroy_sidebar(void)
 {
-	gtk_widget_destroy(file_view_vbox);
+	if (file_view_vbox)
+		gtk_widget_destroy(file_view_vbox);
 }
