@@ -1,7 +1,7 @@
 /*
  *      geanysendmail.c
  *
- *      Copyright 2007-2011, 2013 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
+ *      Copyright 2007-2015 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
  *      Copyright 2007 Enrico Tröger <enrico(dot)troeger(at)uvena(dot)de>
  *      Copyright 2007, 2008 Nick Treleaven <nick(dot)treleaven(at)btinternet(dot)com>
  *      Copyright 2008, 2009 Timothy Boronczyk <tboronczyk(at)gmail(dot)com>
@@ -29,20 +29,18 @@
 #endif
 
 #include <geanyplugin.h>
-#include "icon.h"
+#include "mail-icon.xpm"
 
 GeanyPlugin		*geany_plugin;
 GeanyData		*geany_data;
-GeanyFunctions	*geany_functions;
 
-PLUGIN_VERSION_CHECK(199)
+PLUGIN_VERSION_CHECK(224)
 
 PLUGIN_SET_TRANSLATABLE_INFO(
 	LOCALEDIR,
 	GETTEXT_PACKAGE,
 	_("GeanySendMail"),
-	_("A little plugin to send the current "
-	  "file as attachment by user's favorite mailer"),
+	_("Sends the current file as attachment with your favorite mailer"),
 	VERSION,
 	"Frank Lanitz <frank@frank.uvena.de>")
 
@@ -72,8 +70,6 @@ send_as_attachment(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer g
 	gchar	*command = NULL;
 	GError	*error = NULL;
 	GString	*cmd_str = NULL;
-	GKeyFile 	*config = g_key_file_new();
-	gchar 		*config_dir = g_path_get_dirname(config_file);
 	gchar 		*data;
 
 	doc = document_get_current();
@@ -95,6 +91,8 @@ send_as_attachment(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer g
 			cmd_str = g_string_new(mailer);
 			if ((use_address_dialog == TRUE) && (g_strrstr(mailer, "%r") != NULL))
 			{
+				GKeyFile *config = NULL;
+				gchar *config_dir = NULL;
  				gchar *input = dialogs_show_input(_("Recipient's Address"),
 										GTK_WINDOW(geany->main_widgets->window),
 										_("Enter the recipient's e-mail address:"),
@@ -102,6 +100,7 @@ send_as_attachment(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer g
 
 				if (input)
 				{
+					config = g_key_file_new();
 					g_key_file_load_from_file(config, config_file, G_KEY_FILE_NONE, NULL);
 
 					g_free(address);
@@ -116,6 +115,7 @@ send_as_attachment(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer g
 					return;
 				}
 
+				config_dir = g_path_get_dirname(config_file);
 				if (! g_file_test(config_dir, G_FILE_TEST_IS_DIR) &&
 				      utils_mkdir(config_dir, TRUE) != 0)
  				{
@@ -128,9 +128,9 @@ send_as_attachment(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer g
  					data = g_key_file_to_data(config, NULL, NULL);
  					utils_write_file(config_file, data);
 					g_free(data);
-					g_key_file_free(config);
- 					g_free(config_dir);
  				}
+				g_key_file_free(config);
+				g_free(config_dir);
  			}
 
 			if (! utils_string_replace_all(cmd_str, "%f", locale_filename))
@@ -142,7 +142,6 @@ send_as_attachment(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer g
 				if (! utils_string_replace_all(cmd_str, "%r", address))
  					ui_set_statusbar(FALSE,
 					_("Recipient address placeholder not found. The executed command might have failed."));
-					g_free(address);
 			}
 			else
 			{
@@ -172,8 +171,6 @@ send_as_attachment(G_GNUC_UNUSED GtkMenuItem *menuitem, G_GNUC_UNUSED gpointer g
 	{
 		ui_set_statusbar(FALSE, _("File has to be saved before sending."));
 	}
-
-	g_key_file_free(config);
 }
 
 static void key_send_as_attachment(G_GNUC_UNUSED guint key_id)
@@ -200,7 +197,7 @@ static void add_stock_item(void)
 	}
 	else
 	{
-		GdkPixbuf *pb = gdk_pixbuf_new_from_inline(-1, mail_pixbuf, FALSE, NULL);
+		GdkPixbuf *pb = gdk_pixbuf_new_from_xpm_data(mail_icon);
 		icon_set = gtk_icon_set_new_from_pixbuf(pb);
 		g_object_unref(pb);
 	}
