@@ -26,11 +26,10 @@
 
 GeanyPlugin*           geany_plugin;
 GeanyData*             geany_data;
-GeanyFunctions*        geany_functions;
 
 /*========================================== PLUGIN INFORMATION ==========================================================*/
 
-PLUGIN_VERSION_CHECK(130)
+PLUGIN_VERSION_CHECK(224)
 PLUGIN_SET_TRANSLATABLE_INFO(
     LOCALEDIR,
     GETTEXT_PACKAGE,
@@ -48,10 +47,6 @@ static void xml_format(GtkMenuItem *menuitem, gpointer gdata);
 static void kb_run_xml_pretty_print(G_GNUC_UNUSED guint key_id);
 static void config_closed(GtkWidget* configWidget, gint response, gpointer data);
 
-void plugin_init(GeanyData *data);
-void plugin_cleanup(void);
-GtkWidget* plugin_configure(GtkDialog * dialog);
-
 /*========================================== FUNCTIONS ===================================================================*/
 
 void plugin_init(GeanyData *data)
@@ -59,9 +54,6 @@ void plugin_init(GeanyData *data)
     /* initializes the libxml2 */
     LIBXML_TEST_VERSION
 
-    /* mutilanguage support */
-    main_locale_init(LOCALEDIR, GETTEXT_PACKAGE);
-
     /* put the menu into the Tools */
     main_menu_item = gtk_menu_item_new_with_mnemonic(_("PrettyPrinter XML"));
     ui_add_document_sensitive(main_menu_item);
